@@ -61,15 +61,15 @@ class EpicDetectorRecipe(Recipe):
 
         # Link ip6 repo to epic, as IP6 should be linked to installed epic
         self.config['ip6_link_source'] = "{install_path_ip6}/share/ip6".format(**self.config)
-        self.config['ip6_link_target'] = "{install_path_epic}/share/ecce/ip6".format(**self.config)
+        self.config['ip6_link_target'] = "{install_path_epic}/share/epic/ip6".format(**self.config)
 
         # cmake command:
         # the  -Wno-dev  flag is to ignore the project developers cmake warnings for policy CMP0075
-        self.config['build_cmd_epic'] = "cmake -w -DCMAKE_INSTALL_PREFIX={install_path_epic} -DCMAKE_CXX_STANDARD={cxx_standard} {source_path_epic}" \
+        self.config['build_cmd_epic'] = "cmake -DCMAKE_INSTALL_PREFIX={install_path_epic} -DCMAKE_CXX_STANDARD={cxx_standard} {source_path_epic}" \
                          "&& cmake --build . -- -j {build_threads}" \
                          "&& cmake --build . --target install" \
                          .format(**self.config)
-        self.config['build_cmd_ip6'] = "cmake -w -DCMAKE_INSTALL_PREFIX={install_path_ip6} -DCMAKE_CXX_STANDARD={cxx_standard} {source_path_ip6}" \
+        self.config['build_cmd_ip6'] = "cmake -DCMAKE_INSTALL_PREFIX={install_path_ip6} -DCMAKE_CXX_STANDARD={cxx_standard} {source_path_ip6}" \
                          "&& cmake --build . -- -j {build_threads}" \
                          "&& cmake --build . --target install" \
                          .format(**self.config)
